Learn R Programming

machina (version 0.1.6)

drawRows: drawRows

Description

This adds one or multiple rows to a chart window at https://account.machi.na.

Usage

drawRows(rowsArray,startDate = NULL,endDate = NULL,chartId='', verbose = FALSE)

Arguments

rowsArray
Not required, whether to produce verbose output (default = FALSE)
startDate
Not required, start date (default = NULL)
endDate
Not required, end date (default = NULL)
chartId
Not required, chart ID (default = '')
verbose
Not required, whether to produce verbose output (default = FALSE)

Value

This adds one or multiple rows to a chart window at https://account.machi.na.

Details

This adds one or multiple rows to a chart window at https://account.machi.na.

Examples

Run this code
  #  chart <- drawRows(c(2,3))

Run the code above in your browser using DataLab