Learn R Programming

machina (version 0.1.6)

listStrategies: listModels

Description

This connects to the Machina web service, and gets a list of your models.

Usage

listStrategies(verbose = FALSE)

Arguments

verbose
Not required, whether to produce verbose output (default = FALSE)

Value

This function returns a list of your models.

Details

This connects to Machina web service, and and gets a list of your strategies.

Examples

Run this code
  #  listStrategies()

Run the code above in your browser using DataLab